using System;
using System.IO;
using System.Xml;
using System.Xml.Serialization;
using System.Xml.XPath;
using log4net;

namespace Com.Raritan.KxGui.Preferences;

public class DevicePreferencesManager
{
	private static readonly string Filepath = Path.Combine(Utils.HOME_DIR, "DeviceTree.xml");

	private static readonly ILog Logger = LogManager.GetLogger(typeof(DevicePreferencesManager));

	private readonly string _deviceAddress;

	public string DeviceAddress => _deviceAddress;

	public DevicePreferences DevicePreferences { get; private set; }

	public DevicePreferencesManager(string deviceAddress)
	{
		_deviceAddress = deviceAddress;
		XmlDevicePreferences xmlDevicePreferences = LoadPreferences(DeviceAddress);
		DevicePreferences = new DevicePreferences(xmlDevicePreferences.ColorDepthAsEnum, xmlDevicePreferences.SmoothingAsEnum, xmlDevicePreferences.ConnectionSpeedAsEnum, xmlDevicePreferences.SmartCardReaderName, xmlDevicePreferences.IpAddress, xmlDevicePreferences.Description, xmlDevicePreferences.DnsName, xmlDevicePreferences.ProductType, xmlDevicePreferences.Port, xmlDevicePreferences.ConnectPlaybackDevice, xmlDevicePreferences.PlaybackDevice, xmlDevicePreferences.PlaybackFormat, xmlDevicePreferences.PlaybackBufferSize, xmlDevicePreferences.ConnectCaptureDevice, xmlDevicePreferences.CaptureDevice, xmlDevicePreferences.CaptureFormat, xmlDevicePreferences.CaptureBufferSize);
	}

	private static XmlDevicePreferences LoadPreferences(string deviceAddress)
	{
		//IL_0094: Unknown result type (might be due to invalid IL or missing references)
		//IL_009a: Expected O, but got Unknown
		XmlDocument xmlDocument = Utils.GetXmlDocument(Filepath);
		if (xmlDocument == null)
		{
			Logger.Debug(Filepath + " not found, using default DevicePreferences");
			return new XmlDevicePreferences(null, null, null, deviceAddress, null, null, null, null, null, null, connectPlaybackDevice: true, null, null, 120, connectCaptureDevice: false, null, null, 120);
		}
		XmlNode val = ((XmlNode)xmlDocument).SelectSingleNode("preferences/root[@type='user']/node[@name='RaritanDevices']/node[@name='" + deviceAddress + "']");
		if (val != null)
		{
			string transformedXml = Utils.GetTransformedXml("ToDevPreferences.xslt", val.OuterXml);
			XmlSerializer val2 = new XmlSerializer(typeof(XmlDevicePreferences));
			try
			{
				return (XmlDevicePreferences)val2.Deserialize((TextReader)new StringReader(transformedXml));
			}
			catch (InvalidOperationException exception)
			{
				Logger.Warn("Error Reading XmlDevicePreferences, using default", exception);
				return new XmlDevicePreferences(null, null, null, deviceAddress, null, null, null, null, null, null, connectPlaybackDevice: true, null, null, 120, connectCaptureDevice: false, null, null, 120);
			}
		}
		return new XmlDevicePreferences(null, null, null, deviceAddress, null, null, null, null, null, null, connectPlaybackDevice: true, null, null, 120, connectCaptureDevice: false, null, null, 120);
	}

	public void PersistDevicePreferences(DevicePreferences pref)
	{
		string data = Utils.Serialize(new XmlDevicePreferences(pref, DeviceAddress));
		XmlDocument val = Utils.GetXmlDocument(Filepath);
		if (val == null)
		{
			val = Utils.GetPrefernecesTemplate("DevPreferencesTemplate.xml");
		}
		XPathNavigator val2 = ((XmlNode)val).CreateNavigator();
		string text = "preferences/root[@type='user']/node[@name='RaritanDevices']/node[@name='" + DeviceAddress + "']";
		XPathNavigator val3 = val2.SelectSingleNode(text);
		if (val3 == null)
		{
			val3 = val2.SelectSingleNode("preferences/root[@type='user']/node[@name='RaritanDevices']");
			val3.AppendChild(Utils.GetTransformedXml("FromDevPreferences.xslt", data));
		}
		else
		{
			XPathNavigator val4 = val2.SelectSingleNode(text + "/map/entry[@key='g2ConnectionSpeed']");
			if (val4 != null)
			{
				val4.DeleteSelf();
			}
			val4 = val2.SelectSingleNode(text + "/map/entry[@key='g2Smoothing']");
			if (val4 != null)
			{
				val4.DeleteSelf();
			}
			val4 = val2.SelectSingleNode(text + "/map/entry[@key='g2ColorDepth']");
			if (val4 != null)
			{
				val4.DeleteSelf();
			}
			val4 = val2.SelectSingleNode(text + "/map/entry[@key='autoMountSmartCardReaderName']");
			if (val4 != null)
			{
				val4.DeleteSelf();
			}
			val4 = val2.SelectSingleNode(text + "/map/entry[@key='ipAddress']");
			if (val4 != null)
			{
				val4.DeleteSelf();
			}
			val4 = val2.SelectSingleNode(text + "/map/entry[@key='dnsName']");
			if (val4 != null)
			{
				val4.DeleteSelf();
			}
			val4 = val2.SelectSingleNode(text + "/map/entry[@key='description']");
			if (val4 != null)
			{
				val4.DeleteSelf();
			}
			val4 = val2.SelectSingleNode(text + "/map/entry[@key='port']");
			if (val4 != null)
			{
				val4.DeleteSelf();
			}
			val4 = val2.SelectSingleNode(text + "/map/entry[@key='productType']");
			if (val4 != null)
			{
				val4.DeleteSelf();
			}
			val4 = val2.SelectSingleNode(text + "/map/entry[@key='connectPlaybackDevice']");
			if (val4 != null)
			{
				val4.DeleteSelf();
			}
			val4 = val2.SelectSingleNode(text + "/map/entry[@key='playbackDevice']");
			if (val4 != null)
			{
				val4.DeleteSelf();
			}
			val4 = val2.SelectSingleNode(text + "/map/entry[@key='playbackFormat']");
			if (val4 != null)
			{
				val4.DeleteSelf();
			}
			val4 = val2.SelectSingleNode(text + "/map/entry[@key='playbackBufferSize']");
			if (val4 != null)
			{
				val4.DeleteSelf();
			}
			val4 = val2.SelectSingleNode(text + "/map/entry[@key='connectCaptureDevice']");
			if (val4 != null)
			{
				val4.DeleteSelf();
			}
			val4 = val2.SelectSingleNode(text + "/map/entry[@key='captureDevice']");
			if (val4 != null)
			{
				val4.DeleteSelf();
			}
			val4 = val2.SelectSingleNode(text + "/map/entry[@key='captureFormat']");
			if (val4 != null)
			{
				val4.DeleteSelf();
			}
			val4 = val2.SelectSingleNode(text + "/map/entry[@key='captureBufferSize']");
			if (val4 != null)
			{
				val4.DeleteSelf();
			}
			val3 = val2.SelectSingleNode(text + "/map");
			val3.AppendChild(Utils.GetTransformedXml("FromDevPrefEntries.xslt", data));
		}
		DevicePreferences = pref;
		try
		{
			val.Save(Filepath);
		}
		catch (Exception exception)
		{
			Logger.Warn("Falied to persist " + Filepath, exception);
			throw;
		}
	}
}
