using System;
using System.Drawing;
using System.Text.RegularExpressions;
using System.Xml.Serialization;
using Com.Raritan.KxGui.Scan;

namespace Com.Raritan.KxGui.Preferences;

[XmlRoot("ApplicationPreferences")]
public class XmlApplicationPreferences
{
	private bool _isUserDefSingleMouseExitHotKey;

	private bool _isUserDefKeyboardMenuHotKey;

	private bool _isUserDefConnectionExitHotKey;

	private string _singleMouseExitHotKey = "Ctrl+Alt+O";

	private string _keyboardMenuHotKey = "Ctrl+Alt+M";

	private string _connectionExitHotKey = "Ctrl+Alt+Q";

	private int _broadcastPort = 5000;

	private string _monitor;

	private int _scanDisplayInterval = 10;

	private int _portScanInterval = 10;

	private string _scanThumbnailSize = "160x120";

	private string _scanOrientation = "Vertical";

	public bool LogEnabled { get; set; }

	public bool EnableLaunchInFS { get; set; }

	public int KeyboardType { get; set; }

	public bool EnableLaunchWithSMM { get; set; }

	public bool EnableLaunchWithScaling { get; set; }

	public bool PinMenuToolbar { get; set; }

	public string SingleMouseExitHotKey
	{
		get
		{
			return _singleMouseExitHotKey;
		}
		set
		{
			if (value == null)
			{
				throw new ArgumentNullException("SingleMouseExitHotKey");
			}
			if (!Regex.Match(value, "Ctrl\\+Alt\\+[A-Z]$").Success)
			{
				throw new ArgumentException("Argument should be in Ctrl+Alt+[A-Z] format");
			}
			_singleMouseExitHotKey = value;
			_isUserDefSingleMouseExitHotKey = true;
		}
	}

	public string KeyboardMenuHotKey
	{
		get
		{
			return _keyboardMenuHotKey;
		}
		set
		{
			if (value == null)
			{
				throw new ArgumentNullException("KeyboardMenuHotKey");
			}
			if (!Regex.Match(value, "Ctrl\\+Alt\\+[A-Z]$").Success)
			{
				throw new ArgumentException("Argument should be in Ctrl+Alt+[A-Z] format");
			}
			_keyboardMenuHotKey = value;
			_isUserDefKeyboardMenuHotKey = true;
		}
	}

	public string ConnectionExitHotKey
	{
		get
		{
			return _connectionExitHotKey;
		}
		set
		{
			if (value == null)
			{
				throw new ArgumentNullException("ConnectionExitHotKey");
			}
			if (!Regex.Match(value, "Ctrl\\+Alt\\+[A-Z]$").Success)
			{
				throw new ArgumentException("Argument should be in Ctrl+Alt+[A-Z] format");
			}
			_connectionExitHotKey = value;
			_isUserDefConnectionExitHotKey = true;
		}
	}

	public int BroadcastPort
	{
		get
		{
			return _broadcastPort;
		}
		set
		{
			if (value > 65535 || value < 0)
			{
				throw new ArgumentOutOfRangeException("BroadcastPort", $"Broadcast port must be a value from  0 to 65535");
			}
			_broadcastPort = value;
		}
	}

	public string Monitor
	{
		get
		{
			return _monitor;
		}
		set
		{
			_monitor = value;
		}
	}

	public int ScanDisplayInterval
	{
		get
		{
			return _scanDisplayInterval;
		}
		set
		{
			if (value > 255 || value < 10)
			{
				throw new ArgumentOutOfRangeException("ScanDisplayInterval", $"Scan display interval port must be a value from  10 to 255");
			}
			_scanDisplayInterval = value;
		}
	}

	public int PortScanInterval
	{
		get
		{
			return _portScanInterval;
		}
		set
		{
			if (value > 255 || value < 10)
			{
				throw new ArgumentOutOfRangeException("PortScanInterval", $"Port scan interval port must be a value from  10 to 255");
			}
			_portScanInterval = value;
		}
	}

	public string ScanThumbnailSize
	{
		get
		{
			return _scanThumbnailSize;
		}
		set
		{
			Size size = Com.Raritan.KxGui.Scan.b.d(value);
			if (size.Width > 500 || size.Width < 10 || size.Height > 500 || size.Height < 10)
			{
				throw new ArgumentOutOfRangeException("ScanThumbnailSize", $"Scan thumbnail size is invalid");
			}
			_scanThumbnailSize = value;
		}
	}

	public string ScanOrientation
	{
		get
		{
			return _scanOrientation;
		}
		set
		{
			if (!value.ToLower().Equals("Horizontal".ToLower()) && !value.ToLower().Equals("Vertical".ToLower()))
			{
				throw new ArgumentOutOfRangeException("ScanOrientation", string.Format("Scan orientation must be \"{0}\" or \"{1}\"", "Horizontal", "Vertical"));
			}
			_scanOrientation = value;
		}
	}

	public bool IsUserDefSingleMouseExitHotKey()
	{
		return _isUserDefSingleMouseExitHotKey;
	}

	public bool IsUserDefKeyboardMenuHotKey()
	{
		return _isUserDefKeyboardMenuHotKey;
	}

	public bool IsUserDefConnectionExitHotKey()
	{
		return _isUserDefConnectionExitHotKey;
	}

	public string GetSingleMouseExitHotKey()
	{
		return SingleMouseExitHotKey;
	}

	public string GetKeyboardMenuHotKey()
	{
		return KeyboardMenuHotKey;
	}

	public string GetConnectionExitHotKey()
	{
		return ConnectionExitHotKey;
	}

	public XmlApplicationPreferences()
	{
	}

	internal XmlApplicationPreferences(ApplicationPreferences p)
	{
		//IL_0107: Unknown result type (might be due to invalid IL or missing references)
		LogEnabled = p.LogEnabled;
		EnableLaunchInFS = p.EnableLaunchInFS;
		KeyboardType = p.KeyboardType;
		SingleMouseExitHotKey = p.SingleMouseExitHotKey;
		KeyboardMenuHotKey = p.KeyboardMenuHotKey;
		BroadcastPort = p.BroadcastPort;
		Monitor = p.Screen;
		EnableLaunchWithSMM = p.EnableLaunchWithSMM;
		EnableLaunchWithScaling = p.EnableLaunchWithScaling;
		ConnectionExitHotKey = p.ConnectionExitHotKey;
		PinMenuToolbar = p.PinMenuToolbar;
		ScanDisplayInterval = p.ScanDisplayInterval;
		PortScanInterval = p.PortScanInterval;
		ScanThumbnailSize = Com.Raritan.KxGui.Scan.b.b(p.ScanThumbnailSize);
		ScanOrientation = Com.Raritan.KxGui.Scan.b.b(p.ScanOrientation);
	}

	public override string ToString()
	{
		return "XmlApplicationPreferences : " + Environment.NewLine + "LogEnabled : " + LogEnabled + Environment.NewLine + "EnableLaunchInFS : " + EnableLaunchInFS + Environment.NewLine + "KeyboardType : " + KeyboardType + Environment.NewLine + "SingleMouseExitHotKey : " + SingleMouseExitHotKey + Environment.NewLine + "KeyboardMenuHotKey : " + KeyboardMenuHotKey + Environment.NewLine + "ConnectionExitHotKey : " + ConnectionExitHotKey + Environment.NewLine + "BroadcastPort : " + BroadcastPort + Environment.NewLine + "Monitor : " + Monitor + Environment.NewLine + "EnableLaunchWithSMM : " + EnableLaunchWithSMM + Environment.NewLine + "EnableLaunchWithScaling : " + EnableLaunchWithScaling + Environment.NewLine + "PinMenuToolbar : " + PinMenuToolbar + Environment.NewLine + "ScanDisplayInterval : " + ScanDisplayInterval + Environment.NewLine + "PortScanInterval : " + PortScanInterval + Environment.NewLine + "ScanThumbnailSize : " + ScanThumbnailSize + Environment.NewLine + "ScanOrientation : " + ScanOrientation;
	}
}
